@@ -1,7 +1,6 @@
 !   make next deinfed if first interaction iformation of nuclius break up
 !   information is needed (make firstcollison=0 in epiev in ephook.f )
 !
-#define BREAKUPINFO
 #undef BREAKUPINFO
 
 #undef  DUMMYDATE
@@ -648,7 +647,7 @@ c/////////////////
 c          init dpm; Thru this call, input data is read via TempDev
 c     Glauber initialization data location is given in that
 c     data and the call to cdpmOpen is made from within dpmjet
-      IEMU = 0
+!      IEMU = 0  ?? 
       CALL DT_DTUINI(NEVTS,EPN,NPMASS,NPCHAR,NTMASS,NTCHAR,IDP,IEMU)
 
       close(TempDev)
