@@ -21,13 +21,12 @@ c
 
 c            
 c        m.f.p (kg/m**2) = abn /xsec(mb)
-
 #if defined (LOOPCHK)
-c////////////////////
       integer ksave/0/, esave/-1./, ncount/0/
       integer ka
       save
       ka = TrackBefMove.p.code
+
       if(ksave .eq. ka .and. esave .eq.  
      *   TrackBefMove.p.fm.p(4)) then
          ncount = ncount +1
@@ -68,6 +67,10 @@ c                hadronic  collisions
             if(xs >  smallxs .and. xs .ne. largexs) then
 c                 fix target
                call cfixTarget(xs)
+            elseif( xs == largexs ) then
+               call cfixTarget(xs)   !  use big xs 
+                         ! to fix the target. pbar annihilation
+                         ! probably A independent.  
             endif
          endif
       endif
@@ -163,7 +166,6 @@ c #include  "Zelemagp.h"
       elseif(ActiveMdl .eq. 'gheisha') then
          call cmfpgheisha(xs, mfp)
       elseif(ActiveMdl .eq. 'incdpm3') then
-
          call cmfpincdpm3(xs, mfp)
       else
          call cmfpother(xs, mfp)
@@ -213,8 +215,13 @@ c     *     (TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass)
 c     *        .lt.  5.0 
 c                     danger 5.0 is fixed &&&&&&&&&&
 c             use total X-section
-            call ctotx(TrackBefMove.p, TargetMassN,  xs)
-            mfp = A2deninv*TargetMassN/xs ! in kg/m2
+            if( ka == knuc .and. TrackBefMove.p.subcode == antip  .and.
+     *           TrackBefMove.p.fm.p(4) <=  TrackBefMove.p.mass ) then
+               call cmfpother(xs,mfp)
+            else
+               call ctotx(TrackBefMove.p, TargetMassN,  xs)
+               mfp = A2deninv*TargetMassN/xs ! in kg/m2
+            endif
          else
             call cmfpother(xs,mfp)
          endif
@@ -278,18 +285,27 @@ c      record /ptcl/ dumkaon, dumproton
 
       ka = TrackBefMove.p.code
       ica = TrackBefMove.p.charge
+      KE = TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass
+
+      if( KE <= 0.) then
+         call cmfpother(xs, mfp)
+         return
+      endif
 
       if( ka .eq. knuc .or. ka .eq. kpion   .or.
      *    ka .eq. kkaon) then
-         KE = TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass
-c     if you change next (10), do similar in cixsec @ call cinelx.
-cc         if( KE < 160.d0  ) then ! consider elastic too
-c******  this correction is only for Cosmos: for Epics check 
-c                                        epixsec.f
+
+            
+         if( JamXs == 1 ) then
+c              for epics see      epixsec.f
             call ctotx(TrackBefMove.p, TargetMassN,  xs)
-cc         else
-cc            call cinelx(TrackBefMove.p, TargetMassN,  xs)
-cc         endif
+         elseif( JamXs == 0 ) then
+            call cinelx(TrackBefMove.p, TargetMassN, TargetAtomicN, xs)
+         else
+            write(0,*) ' JamXs=', JamXs, ' not usable '
+            write(0,*) ' csampNEPIntL.f'
+            stop
+         endif
          mfp = A2deninv*TargetMassN/xs ! in kg/m2
       else
            call cmfpother(xs, mfp)
@@ -450,7 +466,7 @@ c         get mean free path for collision
       elseif(ka .eq. kgnuc ) then
 c          heavy xs
          subcode =TrackBefMove.p.subcode
-         call cAAXsec(subcode, TargetMassN, ek, xs)
+         call cAAXsec2(TrackBefMove.p, TargetMassN, TargetAtomicN, xs)
       elseif(ka .ge. kalfa .and. ka .le. khvymax) then    
          write(0,*) 'will not come; csampNEPIntL'
          stop 
