@@ -20,6 +20,21 @@ c	(->	--------------------------------------------
                                !      2--> old method using vector meson
                                !      3--> below Eg<2.5GeV,  same as 1.
                                !      4     Eg>2.5GeV   same as 2.
+         integer  PhitsXs !2 when phits is used, specify the Xsection to be used.
+                !  D=0.   Use cosmos xsection				
+                !  bit 1--> for p,n use phits xs (last bit is bit 1) (btest(..,0)-->T
+    	        !  bit 2--> for heavy, use phits xs.        
+                !  (phits xs seems to be too large)
+ 
+ 	 integer JamXs        !2      0--> use inelastic channel only with Cosmos cross-section
+                              !      1--> use total cross-section  with Cosmos cross-section
+         integer AAXsec  !2  =1 AA cosmos xsection is normalized to Shen's one at 5GeV/n if
+            !     E/n > 5 GeV and used; E/n< 5 GeV, Shen's xs is used
+            !  =0 AA Shen's xsection is normalzied to cosmos Xsection at 
+            ! 5GeV if E/n < 5 GeV and used; E/n>5 cosmos xs is used
+         integer JamFragment  !2     0--> as original Jam, the spectator breaks into nucleons
+	   !      1--> spectator goes into nucleons, some light heavy ions and heavy remnants
+           !           the method is simple but not so bad.
         logical Freec          !1  if F, the first interaction point is forced to be the injection point else
                                !   the interaction poin is randomly sampled.
 	integer OneDim	       !1  If 0, 3 dimensional simulation. if $\ge$1, one
@@ -217,6 +232,11 @@ c	 <-)	----------------------------------------------
      *  ThinSampling, TimeStructure, HowGeomag,
      *  Trace, TraceDev,  ExactThick, OneDim, Reverse,
      *  Freec,  IncMuonPolari, MagBrem, MagPair, LpmEffect,
-     *  EndLevel, EndLevel2, Eabsorb, HowPhotoP
+     *  EndLevel, EndLevel2, Eabsorb, HowPhotoP, PhitsXS,
+     *  JamXs, AAXsec, JamFragment
  
         common /cZtrackpc/ Generate, Generate2, TraceDir
+ 
+
+
+
